@@ -22,7 +22,7 @@ class AsioWriter(object):
         self.counter += len(data)
         self.writer.write(data)
         if self.counter > self.buffering:
-            await self.push()
+            await self.flush()
 
     async def flush(self):
         await self.writer.drain()
